@@ -330,9 +330,9 @@ extern int yydebug;
 typedef union YYSTYPE YYSTYPE;
 union YYSTYPE
 {
-#line 1301 "parser.y" /* yacc.c:1909  */
+#line 1307 "parser.y" /* yacc.c:1909  */
 
-  char  *id;
+  const char  *id;
   List  *bases;
   struct Define {
     String *val;
