@@ -29,13 +29,11 @@
  *
  */
 
-char cvsroot_pike_cxx[] = "$Id: pike.cxx 13885 2012-11-14 22:16:07Z wsfulton $";
-
 #include "swigmod.h"
 
 #include <ctype.h>		// for isalnum()
 
-static const char *usage = (char *) "\
+static const char *usage = "\
 Pike Options (available with -pike)\n\
      [no additional options]\n\
 \n";
